@@ -1,9 +1,9 @@
 ########################################################################
 # File: Net::Printer
 #
-# $Id: Printer.pm 65 2005-08-08 02:33:57Z cfuhrman $
+# $Id: Printer.pm 71 2008-05-26 17:32:13Z cfuhrman $
 #
-# Chris Fuhrman <chris.fuhrman@tfcci.com>
+# Chris Fuhrman <cfuhrman@panix.com>
 #
 # Description:
 #
@@ -31,6 +31,7 @@ use POSIX qw ( tmpnam );
 use Sys::Hostname;
 
 require Exporter;
+
 # use AutoLoader qw(AUTOLOAD);
 
 our @ISA = qw(Exporter);
@@ -44,8 +45,8 @@ our @ISA = qw(Exporter);
 # will save memory.
 #our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our @EXPORT = qw( printerror printfile printstring queuestatus );
-our $VERSION = '1.04';
+our @EXPORT  = qw( printerror printfile printstring queuestatus );
+our $VERSION = '1.05';
 
 # ----------------------------------------------------------------------
 # Public Methods
@@ -59,14 +60,15 @@ our $VERSION = '1.04';
 #
 #   self - self object
 
-sub printerror {
+sub printerror
+{
 
     # Parameter(s)
     my $self = shift;
 
     return $self->{errstr};
 
-} # printerror()
+}        # printerror()
 
 # Method: printfile
 #
@@ -83,8 +85,8 @@ sub printerror {
 #
 #   1 on success, undef on fail
 
-sub printfile {
-
+sub printfile
+{
     my $dfile;
 
     my $self  = shift;
@@ -93,44 +95,44 @@ sub printfile {
     $self->_logDebug( "invoked ... " );
 
     # Are we being called with a file?
-    $self->{filename} = $pfile
-        if ( $pfile );
+    $self->{filename} = $pfile if( $pfile );
 
-    $self->_logDebug( sprintf( "Filename is %s",
-                               $self->{filename} ) );
+    $self->_logDebug( sprintf( "Filename is %s", $self->{filename} ) );
 
     # File valid?
-    if ( !( $self->{filename} ) ||
-         ( ! -e $self->{filename} )) {
+    if( !( $self->{filename} )
+        || ( !-e $self->{filename} ) )
+    {
 
-        $self->_lpdFatal( sprintf( "Given filename (%s) not valid",
-                                   $self->{filename} ) );
+        $self->_lpdFatal(
+                sprintf( "Given filename (%s) not valid", $self->{filename} ) );
 
         return undef;
 
-    } # file is not valid
-    elsif ( uc( $self->{lineconvert} ) eq "YES") {
-        $dfile = $self->_nlConvert();
-    } # we're using line conversion
-    else {
-        $dfile = $self->{filename};
-    } # file is valid
+    }        # file is not valid
 
-    $self->_logDebug( sprintf("Real Data File    %s",
-                              $dfile) );
+    elsif( uc( $self->{lineconvert} ) eq "YES" )
+    {
+        $dfile = $self->_nlConvert();
+    }        # we're using line conversion
+
+    else
+    {
+        $dfile = $self->{filename};
+    }        # file is valid
+
+    $self->_logDebug( sprintf( "Real Data File    %s", $dfile ) );
 
     # Create Control File
     my @files = $self->_fileCreate();
 
-    $self->_logDebug( sprintf( "Real Control File %s",
-                               $files[0]   ) );
-    $self->_logDebug( sprintf( "Fake Data    File %s",
-                               $files[1] ) );
-    $self->_logDebug( sprintf( "Fake Control File %s", 
-                               $files[2] ) );
+    $self->_logDebug( sprintf( "Real Control File %s", $files[0] ) );
+    $self->_logDebug( sprintf( "Fake Data    File %s", $files[1] ) );
+    $self->_logDebug( sprintf( "Fake Control File %s", $files[2] ) );
 
     # were we able to create control file?
-    unless ( -e $files[0] ) {
+    unless( -e $files[0] )
+    {
         $self->_lpdFatal( "Could not create control file\n" );
         return undef;
     }
@@ -139,54 +141,43 @@ sub printfile {
     my $sock = $self->_socketOpen();
 
     # did we connect?
-    if ( $sock ) {
-        $self->{socket} = $sock;
-    } # if socket opened
-    else {
+    if( $sock ) { $self->{socket} = $sock; }        # if socket opened
+
+    else
+    {
         $self->_lpdFatal( "Could not connect to printer: $!\n" );
         return undef;
-    } # got error opening socket
+    }                                               # got error opening socket
 
     my $resp = $self->_lpdInit();
 
     # did we get a response?
-    unless ( $resp ) {
-
-        $self->_lpdFatal( sprintf(
-                                  "Printer %s on %s not ready!\n",
-                                  $self->{printer},
-                                  $self->{server}
-                                 ) );
+    unless( $resp )
+    {
+        $self->_lpdFatal( sprintf( "Printer %s on %s not ready!\n",
+                                   $self->{printer}, $self->{server} ) );
 
         return undef;
 
     }
 
-    $resp =
-        $self->_lpdSend(
-                        $files[0],
-                        $dfile,
-                        $files[2],
-                        $files[1]
-                       );
-
-    unless ( $resp ) {
+    $resp = $self->_lpdSend( $files[0], $dfile, $files[2], $files[1] );
 
+    unless( $resp )
+    {
         $self->_lpdFatal( "Error Occured sending data to printer\n" );
         return undef;
-
     }
 
     # Clean up
-    $self->{socket}->shutdown(2);
+    $self->{socket}->shutdown( 2 );
 
     unlink $files[0];
-    unlink $dfile
-        if ( uc( $self->{lineconvert} ) eq "YES" );
+    unlink $dfile if( uc( $self->{lineconvert} ) eq "YES" );
 
     return 1;
 
-} # printfile()
+}        # printfile()
 
 # Method: printstring
 #
@@ -200,7 +191,8 @@ sub printfile {
 #
 #   1 on success, undef on fail
 
-sub printstring {
+sub printstring
+{
 
     # Parameter(s)
     my $self = shift;
@@ -210,28 +202,23 @@ sub printstring {
     my $tmpfile = $self->_tmpfile();
     my $fh      = FileHandle->new( "> $tmpfile" );
 
-    unless ($fh) {
-
+    unless( $fh )
+    {
         $self->_lpdFatal( "Could not open $tmpfile: $!\n" );
         return undef;
-
     }
 
     # ... and print it out to our file handle
     print $fh $str;
     $fh->close();
 
-    if ( $self->printfile( $tmpfile ) ) {
+    return undef unless $self->printfile( $tmpfile );
 
-        unlink $tmpfile;
-        return 1;
+    # otherwise return
+    unlink $tmpfile;
+    return 1;
 
-    }
-    else {
-        return undef;
-    }
-
-} # printstring()
+}        # printstring()
 
 # Method: queuestatus
 #
@@ -246,8 +233,8 @@ sub printstring {
 #
 #   Array containing queue status
 
-sub queuestatus {
-
+sub queuestatus
+{
     my @qstatus;
 
     my $self = shift;
@@ -256,44 +243,32 @@ sub queuestatus {
     my $sock = $self->_socketOpen();
 
     # did we connect?
-    if ($sock) {
-        $self->{socket} = $sock;
-    } # we connected
-    else {
-
+    unless( $sock )
+    {
         push( @qstatus,
-              sprintf(
-                      "%s\@%s: Could not connect to printer: $!\n",
-                      $self->{printer},
-                      $self->{server},
-                     ) );
+              sprintf( "%s\@%s: Could not connect to printer: $!\n",
+                       $self->{printer}, $self->{server}, ) );
 
         return @qstatus;
+    }
 
-    } # we couldn't connect
+    # store the socket
+    $self->{socket} = $sock;
 
     # Note that we want to handle remote lpd response ourselves
-    $self->_lpdCommand(
-                       sprintf(
-                               "%c%s\n",
-                               4,
-                               $self->{printer},
-                              ),
-                       0
-                      );
+    $self->_lpdCommand( sprintf( "%c%s\n", 4, $self->{printer} ), 0 );
 
     # Read response from server and format
     eval {
-
         local $SIG{ALRM} = sub { die "timeout\n" };
 
         alarm 15;
         $sock = $self->{socket};
-        while (<$sock>) {
 
+        while( <$sock> )
+        {
             s/($_)/$self->{printer}\@$self->{server}: $1/;
-            push ( @qstatus, $_ );
-
+            push( @qstatus, $_ );
         }
 
         alarm 0;
@@ -303,24 +278,22 @@ sub queuestatus {
     };
 
     # did we get an error retrieving status?
-    if ($@) {
+    if( $@ )
+    {
 
-        push ( @qstatus,
-               sprintf(
-                       "%s\@%s: Timed out getting status from remote printer\n",
-                       $self->{printer},
-                       $self->{server}
-                      ) )
-            if ( $@ =~ /timeout/ );
+        push( @qstatus,
+              sprintf( "%s\@%s: Timed out getting status from remote printer\n",
+                       $self->{printer}, $self->{server} ) )
+            if( $@ =~ /timeout/ );
 
     }
 
     # Clean up
-    $self->{socket}->shutdown(2);
+    $self->{socket}->shutdown( 2 );
 
     return @qstatus;
 
-} # queuestatus()
+}        # queuestatus()
 
 # ----------------------------------------------------------------------
 # Private Methods
@@ -338,24 +311,21 @@ sub queuestatus {
 #
 #   none
 
-sub _logDebug {
+sub _logDebug
+{
 
     # Parameter(s)
     my $self = shift;
     my $msg  = shift;
 
-    $msg  =~ s/\n//;
+    $msg =~ s/\n//;
 
-    my @a = caller(1);
+    my @a = caller( 1 );
 
-    printf(
-           "DEBUG-> %-32s: %s\n",
-           $a[3],
-           $msg
-          )
-        if ( uc( $self->{debug} ) eq "YES" );
+    printf( "DEBUG-> %-32s: %s\n", $a[3], $msg )
+        if( uc( $self->{debug} ) eq "YES" );
 
-} # _logDebug()
+}        # _logDebug()
 
 # Method: _lpdFatal
 #
@@ -370,28 +340,23 @@ sub _logDebug {
 #
 #   1
 
-sub _lpdFatal {
-
+sub _lpdFatal
+{
     my $self = shift;
     my $msg  = shift;
 
-    $msg            =~ s/\n//;
+    $msg =~ s/\n//;
 
-    my @a           = caller();
+    my @a = caller();
 
-    my $errstr      =  sprintf(
-                               "ERROR:%s[%d]: %s",
-                               $a[0],
-                               $a[2],
-                               $msg,
-                              );
+    my $errstr = sprintf( "ERROR:%s[%d]: %s", $a[0], $a[2], $msg, );
 
-    $self->{errstr} =  $errstr;
+    $self->{errstr} = $errstr;
 
     carp "$errstr\n";
     return 1;
 
-} # _lpdFatal()
+}        # _lpdFatal()
 
 # Preloaded methods go here.
 
@@ -407,8 +372,8 @@ sub _lpdFatal {
 #
 #   name of temporary file
 
-sub _tmpfile {
-
+sub _tmpfile
+{
     my $name;
     my $fh;
 
@@ -416,14 +381,14 @@ sub _tmpfile {
 
     # try new temporary filenames until we get one that didn't already
     # exist
-    do { $name = tmpnam() } until $fh = IO::File->new($name,
-                                                      O_RDWR|O_CREAT|O_EXCL);
+    do { $name = tmpnam() }
+        until $fh = IO::File->new( $name, O_RDWR | O_CREAT | O_EXCL );
 
     $fh->close();
 
     return $name;
 
-} # _tmpfile()
+}        # _tmpfile()
 
 # Method: _nlConvert
 #
@@ -439,34 +404,35 @@ sub _tmpfile {
 #
 #   name of file containing strip'd text, undef on fail
 
-sub _nlConvert {
-
-    my $self  = shift;
+sub _nlConvert
+{
+    my $self = shift;
 
     $self->_logDebug( "invoked ... " );
 
     # Open files
     my $ofile = $self->{filename};
     my $nfile = $self->_tmpfile();
-    my $ofh   = FileHandle->new( "$ofile"   );
+    my $ofh   = FileHandle->new( "$ofile" );
     my $nfh   = FileHandle->new( "> $nfile" );
 
-    unless ( $ofh ) {
-        $self->_logDebug ( "Cannot open $ofile: $!\n" );
+    unless( $ofh )
+    {
+        $self->_logDebug( "Cannot open $ofile: $!\n" );
         return undef;
     }
 
-    unless ( $nfh ) {
-        $self->_logDebug ( "Cannot open $nfile: $!\n" );
+    unless( $nfh )
+    {
+        $self->_logDebug( "Cannot open $nfile: $!\n" );
         return undef;
     }
 
-    while (<$ofh>) {
-
+    while( <$ofh> )
+    {
         s/\n/\n\r/;
         print $nfh $_;
-
-    } # while ($ofh)
+    }        # while ($ofh)
 
     # Clean up
     $ofh->close();
@@ -474,7 +440,7 @@ sub _nlConvert {
 
     return $nfile;
 
-} # _nlConvert()
+}        # _nlConvert()
 
 # Method: _socketOpen
 #
@@ -488,42 +454,38 @@ sub _nlConvert {
 #
 #   socket
 
-sub _socketOpen {
-
+sub _socketOpen
+{
     my $sock;
 
     my $self = shift;
 
     # See if user wants rfc1179 compliance
-    if ( uc( $self->{rfc1179} ) eq "NO" ) {
-
-        $sock = IO::Socket::INET->new(
-                                      Proto    => 'tcp',
-                                      PeerAddr => $self->{server},
-                                      PeerPort => $self->{port},
-                                     );
-
+    if( uc( $self->{rfc1179} ) eq "NO" )
+    {
+        $sock = IO::Socket::INET->new( Proto    => 'tcp',
+                                       PeerAddr => $self->{server},
+                                       PeerPort => $self->{port}, );
     }
-    else {
+
+    else
+    {
 
         # RFC 1179 says "source port be in the range 721-731"
-        foreach my $p ( 721 .. 731 ) {
-
-            $sock = IO::Socket::INET->new(
-                                          PeerAddr  => $self->{server},
-                                          PeerPort  => $self->{port},
-                                          Proto     => 'tcp',
-                                          LocalPort => $p
-                                         )
+        foreach my $p ( 721 .. 731 )
+        {
+            $sock = IO::Socket::INET->new( PeerAddr  => $self->{server},
+                                           PeerPort  => $self->{port},
+                                           Proto     => 'tcp',
+                                           LocalPort => $p )
                 and last;
-
-        } # Iterate through ports
+        }        # Iterate through ports
 
     }
 
     return $sock;
 
-} # _socketOpen()
+}        # _socketOpen()
 
 # Method: _fileCreate
 #
@@ -543,14 +505,14 @@ sub _socketOpen {
 #    - name of data file
 #    - name of control file
 
-sub _fileCreate {
-
+sub _fileCreate
+{
     my %chash;
 
     my $self = shift;
 
-    my $myname  = hostname();
-    my $snum    = int ( rand 1000 );
+    my $myname = hostname();
+    my $snum   = int( rand 1000 );
 
     # Fill up hash
     $chash{'1H'} = $myname;
@@ -558,49 +520,36 @@ sub _fileCreate {
     $chash{'3J'} = $self->{filename};
     $chash{'4C'} = $myname;
 
-    $chash{'5f'} = sprintf(
-                           "dfA%03d%s",
-                           $snum,
-                           $myname,
-                          );
+    $chash{'5f'} = sprintf( "dfA%03d%s", $snum, $myname );
 
-    $chash{'6U'} = sprintf(
-                           "cfA%03d%s",
-                           $snum,
-                           $myname,
-                          );
+    $chash{'6U'} = sprintf( "cfA%03d%s", $snum, $myname, );
 
     $chash{'7N'} = $self->{filename};
 
     my $cfile = $self->_tmpfile();
     my $cfh   = new FileHandle "> $cfile";
 
-    unless ($cfh) {
-
+    unless( $cfh )
+    {
         $self->_logDebug( "_fileCreate:Could not create file $cfile: $!" );
         return undef;
+    }        # if we didn't get a proper filehandle
 
-    } # if we didn't get a proper filehandle
-
-    foreach my $key ( sort keys %chash ) {
-
-        $_        = $key;
+    foreach my $key ( sort keys %chash )
+    {
+        $_ = $key;
 
         s/(.)(.)/$2/g;
 
         my $ccode = $_;
 
-        printf $cfh (
-                     "%s%s\n",
-                     $ccode,
-                     $chash{$key},
-                    );
+        printf $cfh ( "%s%s\n", $ccode, $chash{$key} );
 
-    } # foreach $key ( sort keys %chash )
+    }        # foreach $key ( sort keys %chash )
 
     return ( $cfile, $chash{'5f'}, $chash{'6U'} );
 
-} # _fileCreate()
+}        # _fileCreate()
 
 # Method: _lpdCommand
 #
@@ -619,53 +568,50 @@ sub _fileCreate {
 #
 #   response of lpd command
 
-sub _lpdCommand {
-
+sub _lpdCommand
+{
     my $response;
 
     my $self = shift;
     my $cmd  = shift;
     my $gans = shift;
 
-    $self->_logDebug( sprintf ( "Sending %s",
-                                $cmd ) );
+    $self->_logDebug( sprintf( "Sending %s", $cmd ) );
 
     $self->{socket}->send( $cmd );
 
-    if ( $gans ) {
+    if( $gans )
+    {
 
         # We wait for a response
         eval {
-
             local $SIG{ALRM} = sub { die "timeout\n" };
 
             alarm 5;
-            $self->{socket}->recv( $response, 1024)
+            $self->{socket}->recv( $response, 1024 )
                 or die "recv: $!\n";
 
             1;
-
         };
 
         alarm 0;
 
-        if ($@) {
-
-            if ($@ =~ /timeout/) {
+        if( $@ )
+        {
+            if( $@ =~ /timeout/ )
+            {
                 $self->_logDebug( "Timed out sending command" );
                 return undef;
             }
-
         }
 
-        $self->_logDebug( sprintf( "Got back :%s:",
-                                   $response) );
+        $self->_logDebug( sprintf( "Got back :%s:", $response ) );
 
         return $response;
 
-    } # if ($gans)
+    }        # if ($gans)
 
-} # _lpdCommand()
+}        # _lpdCommand()
 
 # Method: _lpdInit
 #
@@ -680,8 +626,8 @@ sub _lpdCommand {
 #
 #   1 on success, undef on fail
 
-sub _lpdInit {
-
+sub _lpdInit
+{
     my $buf;
     my $retcode;
 
@@ -690,39 +636,32 @@ sub _lpdInit {
     $self->_logDebug( "invoked ... " );
 
     # Create and send ready
-    $buf     = sprintf( "%c%s\n", 2, $self->{printer} );
-    $buf     = $self->_lpdCommand( $buf, 1 );
+    $buf = sprintf( "%c%s\n", 2, $self->{printer} );
+    $buf = $self->_lpdCommand( $buf, 1 );
     $retcode = unpack( "c", $buf );
 
     $self->_logDebug( "Return code is $retcode" );
 
-    if ( ( $retcode =~ /\d/ ) &&
-         ( $retcode == 0 ) ) {
-
-        $self->_logDebug( sprintf(
-                                  "Printer %s on Server %s is okay",
-                                  $self->{printer},
-                                  $self->{server}
-                                 ) );
+    if(    ( $retcode =~ /\d/ )
+        && ( $retcode == 0 ) )
+    {
+        $self->_logDebug( sprintf( "Printer %s on Server %s is okay",
+                                   $self->{printer}, $self->{server} ) );
 
         return 1;
+    }        # remote printer ok
 
-    } # remote printer ok
-    else {
+    else
+    {
+        $self->_lpdFatal( sprintf( "Printer %s on Server %s not okay",
+                                   $self->{printer}, $self->{server} ) );
 
-        $self->_lpdFatal( sprintf(
-                                  "Printer %s on Server %s not okay",
-                                  $self->{printer},
-                                  $self->{server}
-                                 ) );
-        $self->_logDebug( sprintf("Printer said %s",
-                                  $buf ) );
+        $self->_logDebug( sprintf( "Printer said %s", $buf ) );
 
         return undef;
+    }        # remote printer not ok
 
-    } # remote printer not ok
-
-} # _lpdInit()
+}        # _lpdInit()
 
 # Method: _lpdSend
 #
@@ -739,8 +678,8 @@ sub _lpdInit {
 #
 #   1 on success, undef on fail
 
-sub _lpdSend {
-
+sub _lpdSend
+{
     my $self    = shift;
     my $cfile   = shift;
     my $dfile   = shift;
@@ -750,63 +689,54 @@ sub _lpdSend {
     $self->_logDebug( "invoked ... " );
 
     my $lpdhash = {
-                   "3" => { "name" => $p_dfile,
-                            "real" => $dfile },
-                   "2" => { "name" => $p_cfile,
-                            "real" => $cfile },
+                    "3" => { "name" => $p_dfile, "real" => $dfile },
+                    "2" => { "name" => $p_cfile, "real" => $cfile },
                   };
 
-    foreach my $type ( keys %{$lpdhash} ) {
-
-        $self->_logDebug( sprintf(
-                                  "TYPE:%d:FILE:%s:",
-                                  $type,
-                                  $lpdhash->{$type}->{"name"},
-                                 ) );
+    foreach my $type ( keys %{$lpdhash} )
+    {
+        $self->_logDebug(
+              sprintf( "TYPE:%d:FILE:%s:", $type, $lpdhash->{$type}->{"name"}, )
+        );
 
         # Send msg to lpd
         my $size = ( stat $lpdhash->{$type}->{"real"} )[7];
-        my $buf  = sprintf(
-                           "%c%ld %s\n",
-                           $type,                         # Xmit type
-                           $size,                         # size
-                           $lpdhash->{$type}->{"name"},   # name
-                          );
+        my $buf = sprintf( "%c%ld %s\n",
+                           $type,                              # Xmit type
+                           $size,                              # size
+                           $lpdhash->{$type}->{"name"},        # name
+                         );
 
-        $buf     = $self->_lpdCommand( $buf, 1 );
-
-        unless ($buf) {
+        $buf = $self->_lpdCommand( $buf, 1 );
 
+        unless( $buf )
+        {
             carp "Couldn't send data: $!\n";
             return undef;
-
         }
 
-        $self->_logDebug( sprintf( "FILE:%s:RESULT:%s",
-                                   $lpdhash->{$type}->{"name"}, $buf ) );
+        $self->_logDebug(
+            sprintf( "FILE:%s:RESULT:%s", $lpdhash->{$type}->{"name"}, $buf ) );
 
         my $fh = FileHandle->new( $lpdhash->{$type}->{"real"} );
 
-        unless ( $fh ) {
-
-            $self->_lpdFatal( sprintf(
-                                      "Could not open %s: %s\n",
-                                      $lpdhash->{$type}->{"real"},
-                                      $!,
-                                     ) );
+        unless( $fh )
+        {
+            $self->_lpdFatal( sprintf( "Could not open %s: %s\n",
+                                       $lpdhash->{$type}->{"real"}, $!, ) );
 
             return undef;
-
         }
 
         my $blksize = ( stat $fh )[11] || 16384;
 
-        while ( my $len = sysread $fh, $buf, $blksize ) {
-
-            unless ($len) {
+        while( my $len = sysread $fh, $buf, $blksize )
+        {
+            unless( $len )
+            {
 
                 next
-                    if ($! =~ /^Interrupted/);
+                    if( $! =~ /^Interrupted/ );
 
                 carp "Error while reading\n";
                 return undef;
@@ -815,36 +745,32 @@ sub _lpdSend {
 
             my $offset = 0;
 
-            while ( $len ) {
+            while( $len )
+            {
 
-                my $resp    = syswrite(
-                                       $self->{socket},
-                                       $buf,
-                                       $len,
-                                       $offset
-                                      );
+                my $resp = syswrite( $self->{socket}, $buf, $len, $offset );
 
                 next unless $resp;
 
-                $len    -= $resp;
+                $len -= $resp;
                 $offset += $resp;
 
-            } # while there is data in our buffer
+            }        # while there is data in our buffer
 
-        } # while ($len = sysread $fh, $buf, $blksize)
+        }        # while ($len = sysread $fh, $buf, $blksize)
 
         $fh->close();
 
         # Confirm server response
-        $buf = $self->_lpdCommand( sprintf("%c", 0), 1);
+        $buf = $self->_lpdCommand( sprintf( "%c", 0 ), 1 );
 
-        $self->_logDebug( sprintf( "Confirmation status: %s", $buf) );
+        $self->_logDebug( sprintf( "Confirmation status: %s", $buf ) );
 
-    } # foreach $type (keys %lpdhash)
+    }        # foreach $type (keys %lpdhash)
 
     return 1;
 
-} # _lpdSend()
+}        # _lpdSend()
 
 # ----------------------------------------------------------------------
 # Standard publically accessible method
@@ -855,56 +781,50 @@ sub _lpdSend {
 # called when module destroyed
 #
 
-sub DESTROY {
+sub DESTROY
+{
 
     # Parameter(s)
     my $self = shift;
 
     # Just in case :)
-    $self->{socket}->shutdown(2)
-        if ($self->{socket});
+    $self->{socket}->shutdown( 2 )
+        if( $self->{socket} );
 
-} # DESTROY
+}        # DESTROY
 
 # Method: new
 #
 # called when module initialized
 #
 
-sub new {
-
-    my (%vars)   = (
-                    "filename"    => "",
-                    "lineconvert" => "No",
-                    "printer"     => "lp",
-                    "server"      => "localhost",
-                    "port"        => 515,
-                    "rfc1179"     => "No",
-                    "debug"       => "No",
-                    "timeout"     => 15,
-                   );
+sub new
+{
+    my ( %vars ) = ( "filename"    => "",
+                     "lineconvert" => "No",
+                     "printer"     => "lp",
+                     "server"      => "localhost",
+                     "port"        => 515,
+                     "rfc1179"     => "No",
+                     "debug"       => "No",
+                     "timeout"     => 15, );
 
     # Parameter(s);
     my $type   = shift;
     my %params = @_;
     my $self   = {};
 
-    foreach my $var (keys %vars) {
-
-        if (exists $params{$var}) {
-            $self->{$var} = $params{$var};
-        }
-        else {
-            $self->{$var} = $vars{$var};
-        }
-
+    foreach my $var ( keys %vars )
+    {
+        if( exists $params{$var} ) { $self->{$var} = $params{$var}; }
+        else                       { $self->{$var} = $vars{$var}; }
     }
 
     $self->{errstr} = undef;
 
     return bless $self, $type;
 
-} # new
+}        # new
 
 1;
 __END__
@@ -1033,7 +953,7 @@ Net::Printer with a CUPS server.
 
 =head1 AUTHOR
 
-C. M. Fuhrman, chris.fuhrman@tfcci.com
+C. M. Fuhrman, cfuhrman@panix.com
 
 =head1 SEE ALSO
 
